@@ -1,6 +1,6 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 
-from purchase import *
-from configuration import *
-from invoice import *
+from .purchase import *
+from .configuration import *
+from .invoice import *
